**************************
``matplotlib.projections``
**************************

.. automodule:: matplotlib.projections
   :members:
   :show-inheritance:

Built-in projections
====================
Matplotlib has built-in support for polar and some geographic projections.
See the following pages for more information:

.. toctree::
   :maxdepth: 1

   projections/polar
   projections/geo
